//
//  MCLShare.h
//
//  An online version of the documentation can be found at https://docs.megacool.co
//
//  Do you feel like this reading docs? (╯°□°）╯︵ ┻━┻  Give us a shout if there's anything that's
//  unclear and we'll try to brighten the experience. We can sadly not replace flipped tables.
//

#import <Foundation/Foundation.h>
#import "MCLReferralCode.h"

/***/
typedef NS_ENUM(NSInteger, MCLShareState) {
    MCLShareStateSent = 0,
    MCLShareStateClicked,
    MCLShareStateOpened,
    MCLShareStateInstalled,
};


/**
 MCLShare holds information about a share, like which state it has (MCLShareStateSent,
 MCLShareStateClicked, MCLShareStateOpened or MCLShareStateInstalled), the URL and custom data.
 */
@interface MCLShare : NSObject
NS_ASSUME_NONNULL_BEGIN

/**
 Unique referral code for each share which is part of the link.

 The referral code is assigned when the share is shared, thus not available when you've
 instantiated the share yourself.
 */
@property(readonly, strong) MCLReferralCode *referralCode;


/**
 State of the share: MCLShareStateSent, MCLShareStateClicked, MCLShareStateOpened or
 MCLShareStateInstalled
 */
@property(readonly) MCLShareState state;


/**
 Timestamp of when the share was created
 */
@property(readonly, strong) NSDate *createdAt;


/**
 Timestamp of the last update to the share
 */
@property(readonly, strong) NSDate *updatedAt;


/**
 Data associated with the share object
 */
@property(readonly, strong) NSDictionary *data;


/**
 URL that is associated with the share object.

 This is the URL you should use to navigate within the app, but the shared url will have
 https://mgcl.co/<yourIdentifier> prepended and `_m=<referralCode>` appended to it. If not
 given defaults to `@"/"`. The URL will be normalized by adding leading slash to the path if
 absent, and stripping any trailing slash.
 */
@property(nonatomic, readonly, strong) NSURL *URL;

NS_ASSUME_NONNULL_END
@end
